@@ -84,6 +84,8 @@ class _HTML_Writer(object):
                 rel = self._what(what), href = str(uri)))
 
 RE_TIGHT_COMMA = re.compile(r",(\S)")
+RE_WIDOW = re.compile(r'( \W+$|\s.$)')
+RE_UPDATE = re.compile(r'\s*updated?:\s*', re.I)
 
 class PubInfo(object):
     def __init__(self):
@@ -162,6 +164,11 @@ class DublinCore(object):
     # load local role map as default
     role_map = ROLES
     inverse_role_map = {v.lower(): k for k, v in ROLES.items()}
+    inverse_role_map.update({
+            'author of afterword': 'aft',
+            'author of colophon': 'aft',
+            'author of introduction': 'aui',
+    })
 
     # load local language map as default
     language_map = gg.language_map
@@ -204,17 +211,17 @@ class DublinCore(object):
             # Hack to display 9999? if only d2 is set
             if d2 and not d1:
                 if d2 < 0:
-                    return "%d? BCE" % abs(d2)
+                    return "%d? BCE" % abs(d2 - 1)
                 return "%d?" % d2
             if not d1:
                 return ''
             if d2 and d1 != d2:
                 d3 = max(d1, d2)
                 if d3 < 0:
-                    return "%d? BCE" % abs(d3)
+                    return "%d? BCE" % abs(d3 - 1)
                 return "%d?" % d3
             if d1 < 0:
-                return "%d BCE" % abs(d1)
+                return "%d BCE" % abs(d1 - 1)
             return str(d1)
 
         born = format_dates(author.birthdate, author.birthdate2)
@@ -245,7 +252,9 @@ class DublinCore(object):
 
 
     @staticmethod
-    def make_pretty_name(name):
+    def make_pretty_name(name, role='aut'):
+        if role in {'publ'}:
+            return name
         """ Reverse author name components """
         rev = ' '.join(reversed(name.split(', ')))
         rev = re.sub(r'\(.*\)', '', rev)
@@ -282,13 +291,20 @@ class DublinCore(object):
                 return format_string % (float(size) / threshold)
         return '%d B' % size
 
-
     def make_pretty_title(self, size = 80, cut_nonfiling = False):
         """ Generate a pretty title for ebook. """
+        def surname(author):
+            if author.marcrel == "pbl":
+                return author.name
+            else:
+                return author.name.split(', ')[0]
 
         def cutoff(title, size):
-            """ Cut string off after size characters. """
-            return textwrap.wrap(title, size)[0]
+            """ Cut string off after size characters. (leave room for …)"""
+            wrapped = textwrap.wrap(title, size - 1)
+            if len(wrapped) == 1:
+                return wrapped[0]
+            return RE_WIDOW.sub('', wrapped[0]) + '…'
 
         title = self.title_file_as if cut_nonfiling else self.title
 
@@ -305,8 +321,8 @@ class DublinCore(object):
         if not creators:
             return cutoff(title, size)
 
-        fullnames = [self.make_pretty_name(author.name) for author in creators]
-        surnames  = [author.name.split(', ')[0] for author in creators]
+        fullnames = [self.make_pretty_name(author.name, role=author.marcrel) for author in creators]
+        surnames  = [surname(author) for author in creators]
 
         for tail in (self.strunk(fullnames), self.strunk(surnames)):
             if len(tail) + title_len < size:
@@ -362,6 +378,9 @@ class DublinCore(object):
 
     def add_author(self, name, marcrel = 'cre'):
         """ Add author. """
+        if not name:
+            warning(f'{name} is empty or null')
+            return
         try:
             role = self.role_map[marcrel]
         except KeyError:
@@ -401,10 +420,11 @@ class DublinCore(object):
     def add_credit(self, new_credit):
         ''' the updates field can contain both a production credit and update notations.
             Updates need to be more sophisticated - updates can be added, credits are singular.
+            only add credit if there's not already a credit.
         '''
         if not new_credit:
             return
-        self.credit = new_credit.strip()
+        self.credit = self.credit or new_credit.strip()
 
 
     def load_from_parser(self, parser):
@@ -455,7 +475,7 @@ class DublinCore(object):
 
     @property
     def title_no_subtitle(self):
-        return self.split_title()[0].strip(': .')
+        return self.split_title()[0].strip(': ')
 
     # as you'd expect to see the names on a cover, last names last.
     def authors_short(self):
@@ -466,21 +486,23 @@ class DublinCore(object):
                 num_auths += 1
                 creators.append(author)
         if num_auths == 1:
-            return DublinCore.make_pretty_name(creators[0].name)
+            return DublinCore.make_pretty_name(creators[0].name, role=creators[0].marcrel)
         if num_auths == 2:
             names = "%s and %s" % (
-                DublinCore.make_pretty_name(creators[0].name),
-                DublinCore.make_pretty_name(creators[1].name)
+                DublinCore.make_pretty_name(creators[0].name, role=creators[0].marcrel),
+                DublinCore.make_pretty_name(creators[1].name, role=creators[0].marcrel)
             )
             return names
         if num_auths > 2:
-            return "%s et al." % DublinCore.make_pretty_name(creators[0].name)
+            return "%s et al." % DublinCore.make_pretty_name(
+                creators[0].name, role=creators[0].marcrel)
         return ''
 
-
+RE_ELEMENTS = re.compile(r'<[^<>]*>')
 def handle_dc_languages(dc, text):
     """ Scan Language: line """
     reset = False
+    text = RE_ELEMENTS.sub('', text)       
     text = text.replace(' and ', ',')
     for lang in text.lower().split(','):
         lang = lang.strip()
@@ -945,7 +967,9 @@ class GutenbergDublinCore(DublinCore):
             scan_txt(self, data)
 
         if self.project_gutenberg_id is None:
-            raise ValueError('This is not a Project Gutenberg eBook file.')
+            info('There is no  Project Gutenberg eBook number for this book in the source file.')
+            if not self.title:
+                raise ValueError('This may not be a Project Gutenberg eBook file.')
 
 
 # use PGDCObject if you want a DublinCoreObject that uses a database if available
