@@ -36,7 +36,6 @@ from .Models import (Alias, Attribute, Author, Book, BookAuthor, Category, File,
 RE_YEARS = re.compile(r'(.*)([12]\d\d\d)') # no years before 1000
 RE_CRLF = re.compile(r'[\n\r]+', flags=re.M)
 RE_PLACE = re.compile(r'^\[?([\w\. ]*):')
-RE_UPDATE = re.compile(r'\s*updated?:\s*', re.I)
 
 class DublinCoreObject(DublinCore.GutenbergDublinCore):
     """ Augment GutenbergDublinCore class. """
@@ -115,8 +114,8 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
                 for c_year in s.split('$c')[1].split('$')[0].split(','):
                     year_match = RE_YEARS.search(c_year)
                     if year_match:
-                        yrtype = year_match.group(1).strip() if year_match.group(1).strip() else 'copyright'
-                        years.append((yrtype, year_match.group(2)))
+                        yrtype = year_match.group(1).strip('\r\t\n []') if year_match.group(1).strip('\r\t\n []') else 'copyright'
+                        yrtype = 'copyright' if yrtype.lower() == 'c' else yrtype
                 s = s.split('$c')[0]
             if '$b' in s:
                 publisher = s.split('$b')[1].split('$')[0].strip(' :,.;[]')
@@ -139,10 +138,6 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
 
             return (place, publisher, years)
 
-        def clean_credit(s):
-            # parse out updates
-            return RE_UPDATE.split(s)[0].strip()
-
         book = self.load_book(ebook)
         if not book:
             return
@@ -187,7 +182,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             elif marc.code == '505':
                 self.contents = marc.text
             elif marc.code == '508':
-                self.credit = clean_credit(marc.text)
+                self.credit = DublinCore.RE_UPDATE.split(marc.text)[0].strip()
             elif marc.code == '904':
                 self.scan_urls = marc.text
             elif marc.code == '905':
@@ -323,7 +318,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
 
         session = self.get_my_session()
         if self.book.updatemode != updatemode:
-            self.add_attribute(self.book, [self.credit], marc=508)
+            self.add_attribute(self.book, self.credit, marc=508)
             session.commit()
             return
 
@@ -379,7 +374,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             self.add_attribute(self.book, self.pubinfo.country, marc=907)
 
         if self.credit:
-            self.add_attribute(self.book, [self.credit], marc=508)
+            self.add_attribute(self.book, self.credit, marc=508)
 
         if self.scan_urls:
             self.add_attribute(self.book, self.scan_urls, marc=904)
@@ -403,6 +398,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             book.authors[:] = []
 
         session = self.get_my_session()
+        first = True
         for dc_author in self.authors:
             author = self.get_or_create_author(dc_author.name)
             if hasattr(dc_author, 'birthdate'):
@@ -414,7 +410,13 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             if not role_type:
                 error("%s is not a valid role.", role_type.role)
                 continue
-            book.authors.append(BookAuthor(author=author, role_type=role_type))
+            book.authors.append(BookAuthor(
+                author=author,
+                role_type=role_type,
+                heading=1 if first else 2
+                ))
+            if first:
+                first = False
         return True
 
 
@@ -423,6 +425,8 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
 
         def is_good_match(db_str, name):
             ''' make sure we're not matching in the middle of a name '''
+            db_str = db_str.lower()
+            name = name.lower()
             if name not in db_str:
                 return False
             [before, after] = db_str.split(name, 1)
